@@ -61,15 +61,18 @@ static const gchar *author_credits[] = {
   "Ross Burton  <ross burtonini com>",
   "Damien Carbery  <damien carbery sun com>",
   "Anders Carlsson  <andersca codefactory se>",
+  "Ed Catmur  <ed catmur co uk>",
   "Nicholas Curran  <quasar austar net au>",
   "John Fleck  <jfleck inkstain net>",
   "Sebastian Heinlein <glatzor pimpzkru de>",
   "James Henstridge  <james daa com au>",
-  "Mihai T  Lazarescu  <mihai email it>",
+  "Chris Lahey  <clahey ximian com>",
+  "Mihai T Lazarescu  <mihai email it>",
   "Sebastian Kapfer <sebastian_kapfer web de>",
   "Tomasz Koczko  <kloczek pld org pl>",
   "Jordi Mallach  <jordi sindominio net>",
   "Kjartan Maraas  <kmaraas gnome org>",
+  "Breda McColgan  <breda mccolgan sun com>",
   "Baptiste Mille-Mathias  <bmm80 free fr>",
   "Buhan Milne  <bgmilne linux-mandrake com>",
   "Christian Monneckes  <c-w-m gmx de>",
@@ -78,6 +81,7 @@ static const gchar *author_credits[] = {
   "Jan Arne Petersen  <jpetersen uni-bonn de>",
   "Kevin C  Krinke  <kckrinke opendoorsoftware com>",
   "Kristian Rietveld  <kris gtk org>",
+  "Lucas Rocha  <lucasr im ufba br>",
   "Christian Rose  <menthos menthos com>",
   "Jakub Steiner  <jimmac ximian com>",
   "Luke Suchocki  <gnome lukiepoo com>",
@@ -92,6 +96,7 @@ static const gchar *author_credits[] = {
   "Taneem Ahmed  <taneem bengalinux org>",
   "Takeshi Aihana <aihana gnome gr jp>",
   "Amanpreet Singh Alam  <amanlinux netscape net>",
+  "Metin Amiroff  <metin karegen com>",
   "Sanlig Badral  <badral openmn org>",
   "John C Barstow  <jbowtie amathaine com>",
   "Aygimantas Beruka  <uid0 tuxfamily org>",
@@ -104,7 +109,8 @@ static const gchar *author_credits[] = {
   "Fatih Demir  <kabalak gtranslator org>",
   "Laurent Dhima  <laurenti alblinux net>",
   "Paul Duffy <dubhthach frink nuigalway ie>",
-  " Laszlo Dvornik  <dvornik gnome hu>",
+  "Laszlo Dvornik  <dvornik gnome hu>",
+  "Maxim Dziumanenko  <mvd mylinux com ua>",
   "Francisco Javier Fernandez  <serrador arrakis es>",
   "Artur Flinta  <aflinta cvs gnome org>",
   "Alessio Frusciante  <algol firenze linux it>",
@@ -112,7 +118,9 @@ static const gchar *author_credits[] = {
   "Pablo Gonzalo del Campo  <pablodc bigfoot com>",
   "Dhurba Gnawali  <dhurbagnawali hotmail com>",
   "Sammi Gunnarsson  <sammi techattack nu>",
+  "Martin Willemoes Hansen  <mwh sysrq dk>",
   "Dafydd Harries  <daf parnassus ath cx>",
+  "Raphael Higino  <raphaelh cvs gnome org>",
   "Wang Jian  <lark linux net cn>",
   "Guntupalli Karunakar  <karunakar freedomink org>",
   "Tomas Kuliavas  <tokul users sourceforge net>",
@@ -120,6 +128,7 @@ static const gchar *author_credits[] = {
   "Iaki Larraaga  <dooteo euskalgnu org>",
   "Ole Laursen  <olau hardworking dk>",
   "Toivo Leedjrv  <toivo linux ee>",
+  "David Lodge  <dave cirt net>",
   "Duarte Loreto  <happyguy_pt hotmail com>",
   "Johanna Makkonen  <johanna makkonen iki fi>",
   "Jordi Mallach  <jordi sindominio net>",
@@ -136,10 +145,12 @@ static const gchar *author_credits[] = {
   "Metin Omirov  <metin karegen com>",
   "Gareth Owen  <gowen72 yahoo com>",
   "Kostas Papadimas  <pkst gmx net>",
+  "Ankit Patel  <ankit redhat com>",
   "Sami Pesonen  <sampeson iki fi>",
   "Roozbeh Pournader  <roozbeh sharif edu>",
   "Jarkko Ranta  <jjranta cc joensuu fi>",
   "Rostislav Raykov  <zbrox dir bg>",
+  "Hendrik Richter  <hendrik gnome de org>",
   "Christian Rose  <menthos menthos com>",
   "Changwoo Ryu  <cwryu debian org>",
   "Pablo Saratxaga  <pablo mandrakesoft com>",
@@ -291,7 +302,7 @@ zenity_create_boutique (void)
 
   window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 
-  zenity_util_set_window_icon (window, ZENITY_IMAGE_FULLPATH ("zenity.png"));
+  zenity_util_set_window_icon (window, NULL, ZENITY_IMAGE_FULLPATH ("zenity.png"));
   canvas = zenity_create_monk ();
   gtk_container_add (GTK_CONTAINER (window), canvas);
 
@@ -374,7 +385,7 @@ zenity_about (ZenityData *data)
   g_signal_connect (G_OBJECT (dialog), "key_press_event",
                     G_CALLBACK (zenity_zen_wisdom), glade_dialog);
 
-  zenity_util_set_window_icon (dialog, ZENITY_IMAGE_FULLPATH ("zenity.png"));
+  zenity_util_set_window_icon (dialog, NULL, ZENITY_IMAGE_FULLPATH ("zenity.png"));
 
   image = glade_xml_get_widget (glade_dialog, "zenity_about_image");
 
